@@ -1,20 +1,21 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 750 2009-12-28 16:01:02Z icemac $
+# $Id: tests.py 795 2010-01-19 19:51:13Z icemac $
 
 import icemac.addressbook.testing
-
+import zope.testing.renormalizing
 
 def test_suite():
-    return icemac.addressbook.testing.FunctionalDocFileSuite(
+    suite = icemac.addressbook.testing.FunctionalDocFileSuite(
         "browser/addressbook/addressbook.txt",
         "browser/authentication/login.txt",
+        "browser/entities/bugfix.txt",
         "browser/entities/delete_choice_value.txt",
         "browser/entities/entities.txt",
-        "browser/entities/bugfix.txt",
         "browser/entities/file.txt",
         "browser/export/export.txt",
+        "browser/export/translation.txt",
         "browser/export/userfields.txt",
         "browser/keyword/keyword.txt",
         "browser/masterdata/masterdata.txt",
@@ -25,3 +26,11 @@ def test_suite():
         "browser/rootfolder/rootfolder.txt",
         "browser/search/search.txt",
         )
+    suite.addTest(
+        icemac.addressbook.testing.FunctionalDocFileSuite(
+            # Tests which do not need the default <DATETIME> normalizer:
+            "browser/metadata.txt",
+            checker=zope.testing.renormalizing.RENormalizing([])
+            ))
+    return suite
+
