@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 1124 2009-04-07 18:42:58Z mac $
+# $Id: tests.py 783 2010-01-09 14:28:06Z icemac $
 
 import gocept.reference.verify
 import icemac.addressbook.principals.interfaces
@@ -28,5 +28,5 @@ class TestInterfaces(unittest.TestCase):
 
 
 def test_suite():
-    return icemac.addressbook.testing.UnittestSuite(TestInterfaces)
+    return icemac.addressbook.testing.AddressBookUnittestSuite(TestInterfaces)
 
