@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: sources.py 756 2009-12-28 19:38:47Z icemac $
+# $Id: sources.py 783 2010-01-09 14:28:06Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.export.interfaces
@@ -75,16 +75,3 @@ class ContextByInterfaceSource(
     def getTitle(self, context, value):
         import icemac.addressbook.interfaces # avoid circular import
         return icemac.addressbook.interfaces.ITitle(value)
-
-
-class ExporterSource(zc.sourcefactory.basic.BasicSourceFactory):
-
-    def getValues(self):
-        return zope.component.getAllUtilitiesRegisteredFor(
-            icemac.addressbook.export.interfaces.IExporter)
-
-    def getTitle(self, value):
-        return _(u'${title} (${desc})',
-                 mapping=dict(title=value.title, desc=value.description))
-
-exporter_source = ExporterSource()
